@@ -5,20 +5,21 @@ typedef struct LArgs
     char command[1024];
     unsigned long flags, attrib, workspace, stack, decoration;
     unsigned long pause;
+    Bool iconic;
   } LArgs;
 
 
-Window getleader(Display *display, Window client);
+Window getleader(Window client);
 LArgs arginit(int argc, char **argv);
 
 
-int checkcommand(Display *display, Window leader, LArgs launchargs);
+int checkcommand(Window leader, LArgs launchargs);
 int launch(LArgs launchargs);
-void hintwin(Display *display, Window root, Window win, LArgs launchargs);
+void hintwin(Window root, Window win, LArgs launchargs);
 
 unsigned long getmilliseconds(void);
 
 void usage(void);
-void die(Display *display, char * error);
+void die(char * error);
 int xerror(Display *display, XErrorEvent *error);
 
